@@ -126,6 +126,8 @@ class Mail(SMTPAPIHeader):
             self.files[name] = file_.read()
 
     def add_attachment_stream(self, name, string):
+        if sys.version_info < (3, 0) and isinstance(name, unicode):
+            name = name.encode('uft-8')
         if isinstance(string, str):
             self.files[name] = string
         elif isinstance(string, io.BytesIO):
